@@ -4,11 +4,16 @@ import traceback
 import typing
 
 from .headers import Headers, make_headers
-from .httpexceptions import BadRequest, HTTPException
+from .httpexceptions import BadRequest, HTTPException, InternalServerError
 from .request import Request
-from .responses import Response, make_response
+from .responses import (
+    FileResponse,
+    Response,
+    make_error_response,
+    make_response,
+)
 from .router import Route, Router
-from .types import Handler, Receive, Result, Scope, Send
+from .types import Handler, HeadersType, Receive, Result, Scope, Send
 from .view import View
 
 
@@ -66,7 +71,9 @@ class Baguette:
         self,
         *,
         debug: bool = False,
-        default_headers=None,
+        default_headers: HeadersType = None,
+        static_url_path: str = "static",
+        static_directory: str = "static",
         error_response_type: str = "plain",
         error_include_description: bool = True,
     ):
@@ -74,6 +81,15 @@ class Baguette:
         self.debug = debug
         self.default_headers: Headers = make_headers(default_headers)
 
+        self.static_url_path = static_url_path
+        self.static_directory = static_directory
+
+        self.add_route(
+            path=f"{self.static_url_path}/<filename:path>",
+            handler=self.handle_static_file,
+            name="static",
+        )
+
         if error_response_type not in ("plain", "json", "html"):
             raise ValueError(
                 "Bad response type. Must be one of: 'plain', 'json', 'html'"
@@ -208,11 +224,25 @@ class Baguette:
 
             return await handler(**kwargs)
 
-        except HTTPException as e:
-            return e.response(
+        except HTTPException as http_exception:
+            return make_error_response(
+                http_exception,
                 type_=self.error_response_type,
                 include_description=self.error_include_description,
-                traceback="".join(traceback.format_tb(e.__traceback__))
+                traceback="".join(
+                    traceback.format_tb(http_exception.__traceback__)
+                )
+                if self.debug and http_exception.status_code >= 500
+                else None,
+            )
+        except Exception as exception:
+            traceback.print_exc()
+            http_exception = InternalServerError()
+            return make_error_response(
+                http_exception,
+                type_=self.error_response_type,
+                include_description=self.error_include_description,
+                traceback="".join(traceback.format_tb(exception.__traceback__))
                 if self.debug
                 else None,
             )
@@ -318,6 +348,9 @@ class Baguette:
 
         return decorator
 
+    async def handle_static_file(self, filename: str) -> FileResponse:
+        return FileResponse(self.static_directory, filename)
+
     def run(
         self,
         *,
@@ -490,11 +523,9 @@ class Baguette:
         """
 
         try:
-            import uvicorn  # pragma: no cover
+            import uvicorn
         except ModuleNotFoundError:  # pragma: no cover
-            raise RuntimeError(  # pragma: no cover
-                "Install uvicorn to use app.run()"
-            )
+            raise RuntimeError("Install uvicorn to use app.run()")
 
         last_debug = self.debug
         if isinstance(debug, bool):
